import bb.cascades 1.2
import bb.system 1.2
import "../Sheets"

Container {
    id: bbmNamesContainer
    property alias templateContainerAlias: templateContainer
    
    function onDeleteThisContainer(index) {
        templateContainer.remove(templateContainer.at(index))
    }

    topMargin: _ui.du(3)
    bottomMargin: topMargin * 2
    
    onCreationCompleted: {
        var bbmKnownMap = new Object()
        bbmKnownMap = _settings.value("bbmKnownMap", bbmKnownMap)
        for (var property in bbmKnownMap) {
            if (bbmKnownMap.hasOwnProperty(property)) {
                var thisBbm = bbmNamesTemplate.createObject()
                thisBbm.contactId = property
                thisBbm.bbmName = bbmKnownMap[property]
                templateContainer.insert(0, thisBbm)
                thisBbm.deleteThisContainer.connect(onDeleteThisContainer)
            }
        }
    }
    attachedObjects: [
        ComponentDefinition { 
            id: bbmNamesTemplate
            source: "BbmNamesTemplate.qml"
        },
        ComponentDefinition { id: bbmHowToSheet; BbmHowToSheet {} }
    ]

    Container {
        layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
        ToggleButton {
            id: bbmNotificationsEnabled
            checked: _settings.value("bbmNotificationsEnabled", true)
            verticalAlignment: VerticalAlignment.Center
            onCheckedChanged: {
                _settings.setValue("bbmNotificationsEnabled", checked)
            }
        }
        Label {
            text: qsTr("BBM notifications ") + Retranslate.onLocaleOrLanguageChanged + (bbmNotificationsEnabled.checked ? qsTr("enabled") + Retranslate.onLocaleOrLanguageChanged : qsTr("disabled") + Retranslate.onLocaleOrLanguageChanged)
            multiline: true
            verticalAlignment: VerticalAlignment.Center
            textStyle.fontSize: FontSize.XLarge
        }
    }

    Label {
        text: qsTr("Decide if you want to receive BBM notifications on the watch. Only sender ID is available, the message of the BBM is not readable unfortunately. You can associate an ID with the person's name here too, you'll have to do this manually.\n\nNote that BBM groups needs to show chats in BlackBerry Hub in order to receive their respective notifications.") + Retranslate.onLocaleOrLanguageChanged
        multiline: true
        textStyle.textAlign: TextAlign.Justify
    }
    
    Button {
        text: qsTr("How to enable BBM on Pebble?") + Retranslate.onLocaleOrLanguageChanged
        onClicked: {
            var createdControl = bbmHowToSheet.createObject()
            createdControl.open()
        }
    }
     
    Container {
        visible: bbmNotificationsEnabled.checked
        Container {
            id: templateContainer
        } 
        Button {
            id: addContactButton
            property string newContactId
            property string newBbmName
            
            text: qsTr("Add BBM contact ID") + Retranslate.onLocaleOrLanguageChanged
            enabled: learnNewBbmToggle.checked
            onClicked: {
                contactIdPrompt.show()
            }
            attachedObjects: [
                SystemPrompt {
                    id: contactIdPrompt
                    title: qsTr("Add new BBM contact") + Retranslate.onLocaleOrLanguageChanged
                    body: qsTr("What's the BBM contact ID shown on your Pebble?") + Retranslate.onLocaleOrLanguageChanged
                    inputField.inputMode: SystemUiInputMode.NumericKeypad
                    onFinished: {
                        if (inputFieldTextEntry() != "") {
                            addContactButton.newContactId = inputFieldTextEntry()
                            bbmNamePrompt.show()
                        }
                        else {
                            addContactButton.newContactId = ""
                            addContactButton.newBbmName = ""
                        }
                    }
                },
                SystemPrompt {
                    id: bbmNamePrompt
                    title: qsTr("Add new BBM contact") + Retranslate.onLocaleOrLanguageChanged
                    body: qsTr("What's the name of this contact? (That's the name that will be shown on your Pebble next time)") + Retranslate.onLocaleOrLanguageChanged
                    onFinished: {
                        if (inputFieldTextEntry() != "") {
                            addContactButton.newBbmName = inputFieldTextEntry()
                            var thisBbm = bbmNamesTemplate.createObject()
                            thisBbm.contactId = addContactButton.newContactId
                            thisBbm.bbmName = addContactButton.newBbmName
                            templateContainer.insert(0, thisBbm)
                            thisBbm.deleteThisContainer.connect(onDeleteThisContainer)
                            
                            var bbmKnownMap = new Object()
                            bbmKnownMap = _settings.value("bbmKnownMap", bbmKnownMap)
                            bbmKnownMap[addContactButton.newContactId] = addContactButton.newBbmName
                            _settings.setValue("bbmKnownMap", bbmKnownMap)
                            for (var property in bbmKnownMap) {
                                if (bbmKnownMap.hasOwnProperty(property)) {
                                    console.log(property + " " + bbmKnownMap[property])
                                }
                            }
                        }
                        else {
                            addContactButton.newContactId = ""
                            addContactButton.newBbmName = ""
                        }
                    }
                }
            ]
        }
        
        Container {
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            ToggleButton {
                id: learnNewBbmToggle
                checked: _settings.value("bbmLearningModeOn", false)
                verticalAlignment: VerticalAlignment.Center
                onCheckedChanged: {
                    _settings.setValue("bbmLearningModeOn", checked)
                }
            }
            Label {
                text: qsTr("Learn new BBM contacts") + Retranslate.onLocaleOrLanguageChanged
                multiline: true
                verticalAlignment: VerticalAlignment.Center
                textStyle.fontSize: FontSize.XLarge
            }
        }
        
        Label {
            text: qsTr("Turn this option ON when you want to add a new contact. Once this option is enabled, send a message to the desired contact and come back here to associate the contact ID you will receive on your watch with a name. This option should be turned OFF as soon as you have added all the contacts from who you want to be notified.") + Retranslate.onLocaleOrLanguageChanged
            multiline: true
            textStyle.textAlign: TextAlign.Justify
        }

        Container {
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            ToggleButton {
                id: alertForUnidentifiedBbmContacts
                checked: _settings.value("alertForUnidentifiedBbmContacts", false)
                verticalAlignment: VerticalAlignment.Center
                onCheckedChanged: {
                    _settings.setValue("alertForUnidentifiedBbmContacts", checked)
                }
            }
            Label {
                text: qsTr("Alert for unidentified BBM contacts") + Retranslate.onLocaleOrLanguageChanged
                multiline: true
                verticalAlignment: VerticalAlignment.Center
                textStyle.fontSize: FontSize.XLarge
            }
        }
        
        Label {
            text: qsTr("Turn this option ON when you want to get notified on Pebble even if the contact has not been identified in Bridge. The contact name will not be available.") + Retranslate.onLocaleOrLanguageChanged
            multiline: true
            textStyle.textAlign: TextAlign.Justify
        }
    }
}
