import bb.cascades 1.0
import bb.system 1.2
import "../CustomElements"

Sheet {
    id: appstoreSheet
    onOpened: { Application.setMenuEnabled(false); }
    onClosed: { Application.setMenuEnabled(true); }
    
    Page {
        id: appstorePage
        
        titleBar: TitleBar {
            title: qsTr("Pebble Appstore") + Retranslate.onLanguageChanged
            acceptAction: ActionItem {
                title: qsTr("Ok") + Retranslate.onLanguageChanged
                onTriggered: {
                    appstoreSheet.close()
                }
            }
        }
        
        Container {
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            attachedObjects: [ LayoutUpdateHandler { id: luh } ]
            Container {
                Container {
                    attachedObjects: [ LayoutUpdateHandler { id: luh2 } ]
                    layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                    Button {
                        layoutProperties: StackLayoutProperties { spaceQuota: 1 }
                        text: qsTr("Back") + Retranslate.onLocaleOrLanguageChanged
                        onClicked: webView.goBack()
                        enabled: webView.canGoBack
                    }
                    Button {
                        layoutProperties: StackLayoutProperties { spaceQuota: 1 }
                        text: qsTr("Forward") + Retranslate.onLocaleOrLanguageChanged
                        onClicked: webView.goForward()
                        enabled: webView.canGoForward
                    }
                }
                Container {
                    layout: DockLayout {}
                    minHeight: luh.layoutFrame.height - luh2.layoutFrame.height
                    minWidth: luh.layoutFrame.width - luh2.layoutFrame.width
                    ScrollView {
                        scrollViewProperties {
                            scrollMode: ScrollMode.Vertical 
                            overScrollEffectMode: OverScrollEffectMode.None
                        }
                        scrollRole: ScrollRole.Main
                        WebView {
                            id: webView
                            url: "http://geol.com/pebble/"
                            minHeight: luh.layoutFrame.height
                            minWidth: luh.layoutFrame.width
                            onUrlChanged: {
                                if (url.toString().indexOf("http://geol.com/pebble/") == 0) {
                                    if (_settings.value("showUnofficialPebbleAppstorePbwDialog", true)) {
                                        showPebbleAppstorePbwDialog.show()
                                    }
                                }
                            }
                            
                            attachedObjects: [
                                SystemDialog {
                                    id: showPebbleAppstorePbwDialog
                                    includeRememberMe: true
                                    rememberMeChecked: false
                                    rememberMeText: qsTr("Never show again") + Retranslate.onLocaleOrLanguageChanged
                                    title: qsTr("Download a watchface/watchapp") + Retranslate.onLocaleOrLanguageChanged
                                    body: qsTr("To download a watchface/watchapp, scroll down in the watchface page and click on 'DOWNLOAD' link. Open File Manager, long press on the downloaded file, select 'Open in' and choose Bridge.") + Retranslate.onLocaleOrLanguageChanged
                                    cancelButton.label: ""
                                    onFinished: {
                                        if (rememberMeSelection()) {
                                            _settings.setValue("showUnofficialPebbleAppstorePbwDialog", false)
                                        }
                                    }
                                }
                            ]
                        }
                    }
                    
                    ActivityIndicator { 
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center
                        minWidth: _ui.du(10)
                        minHeight: minWidth
                        running: webView.loading
                        visible: running
                    }
                }
            }
        }
    }
}
