import bb.cascades 1.2
import bb.system 1.2

import ".."
import "../Actions"
import "../CustomElements"
import "../Settings"

Sheet {
    id: settingsSheet
    
    property bool debugModeOn: _settings.value("sendToConsoleDebug", false)
    property bool waSettingsChanged
    
    onOpened: { waSettingsChanged = false; Application.setMenuEnabled(false); }
    onClosed: { Application.setMenuEnabled(true); destroy(); }

    Page {
        titleBar: TitleBar {
            title: qsTr("Settings") + Retranslate.onLanguageChanged
            acceptAction: ActionItem {
                title: qsTr("Ok") + Retranslate.onLanguageChanged
                onTriggered: { 
                    if (waSettingsChanged) 
                        updateBridgeWAToast.show() 
                    else 
                        settingsSheet.close()
                }
            }
        }
        
        actions: [
//            ShareBlogAppOnBarOrSignature {}
        ]
        
        Container {
            id: mainContainer
            
            leftPadding: _ui.du(3)
            rightPadding: leftPadding
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            property double numberOfDoubleTaps: 0
            
            gestureHandlers: [
                DoubleTapHandler {
                    onDoubleTapped: {
                        mainContainer.numberOfDoubleTaps++
                        if (mainContainer.numberOfDoubleTaps == 2) {
                            mainContainer.numberOfDoubleTaps = 0
                            _settings.setValue("sendToConsoleDebug", !_settings.value("sendToConsoleDebug", false))
                            settingsSheet.debugModeOn = _settings.value("sendToConsoleDebug", false)
//                            _settings.setValue("smsBypass", !_settings.value("smsBypass", false))
                            systemToast.body = qsTr("Debug mode ") + (_settings.value("sendToConsoleDebug", false) ? qsTr("ON") : qsTr("OFF"))
                            systemToast.show()
                        }
                    }
                    attachedObjects: [
                        SystemToast {
                            id: systemToast
                        }
                    ]
                }
            ]
            
            ScrollView {
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                Container {
                    topPadding: _ui.du(3)
                    leftPadding: topPadding
                    rightPadding: topPadding
                    bottomPadding: topPadding
                    SectionTemplate {
                        sectionName: qsTr("huBBle") + Retranslate.onLocaleOrLanguageChanged
                        visible: (mainPage.watchUsed == "pebble")
                        HuBBleContainer {}
                        Container {
                            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                            horizontalAlignment: HorizontalAlignment.Center
                            ToggleButton {
                                id: huBBleToggle
                                verticalAlignment: VerticalAlignment.Center
                                checked: _settings.allSettings.useHuBBle
                                onCheckedChanged: {
                                    _settings.setValue("useHuBBle", checked)
                                    
                                    if (checked) {
                                        _settings.setValue("lastSendNewMessageToBridgeWAValueBeforeUseHuBBle", _settings.value("SendNewMessageToBridgeWA"))
                                        _settings.setValue("SendNewMessageToBridgeWA", false)
                                    }
                                    else {
                                        _settings.setValue("SendNewMessageToBridgeWA", _settings.value("lastSendNewMessageToBridgeWAValueBeforeUseHuBBle", true))
                                    }
                                }
                            }
                            Label {
                                text: huBBleToggle.checked ? qsTr("huBBle support enabled") + Retranslate.onLocaleOrLanguageChanged : qsTr("huBBle support disabled") + Retranslate.onLocaleOrLanguageChanged
                                multiline: true
                                verticalAlignment: VerticalAlignment.Center
                                textStyle.fontSize: FontSize.XLarge
                            }
                        }
                    }
                    CustomDivider {}

                    SectionTemplate {
                        sectionName: qsTr("Bridge WA (watchapp)") + Retranslate.onLocaleOrLanguageChanged
                        visible: (mainPage.watchUsed == "pebble")
                        SendNewMessageToBridgeWA {}
                        CustomDivider {}
                        ReplyMessages {}
                    }
                    CustomDivider {}
                    
                    SectionTemplate {
                        sectionName: qsTr("Do Not Disturb") + Retranslate.onLocaleOrLanguageChanged
                        DoNotDisturbOnBedsideMode {}
                        CustomDivider {}
                        DoNotDisturbOnScreenAwake {}
                    }
                    CustomDivider {}

                    SectionTemplate {
                        sectionName: qsTr("Hub accounts notifications") + Retranslate.onLocaleOrLanguageChanged
                        PimNotifications {}
                    }
                    CustomDivider {}
                    
                    SectionTemplate {
                        sectionName: qsTr("Calendar") + Retranslate.onLocaleOrLanguageChanged
                        bottomMargin: _ui.du(3)
                        
                        ShowCalendarNotifications { id: showCalendarNotifications }
                        Container {
                            topMargin: _ui.du(3)
                            CustomDivider { visible: (mainPage.watchUsed == "pebble") }
                            ResendCalendarToTimeline { visible: (mainPage.watchUsed == "pebble") }
                        }
                        Container {
                            topMargin: _ui.du(3)
                            CustomDivider { visible: showCalendarNotifications.showCalendarNotifications }
                            ReminderTime { visible: showCalendarNotifications.showCalendarNotifications }
                        }
                    }
                    CustomDivider {}
                    
                    SectionTemplate {
                        sectionName: qsTr("Weather") + Retranslate.onLocaleOrLanguageChanged
                        bottomMargin: _ui.du(3)

                        ShowWeatherDropDown { id: showWeatherDropDown }
                        Container {
                            topMargin: _ui.du(3)
                            WeatherPinTimeDropDown { visible: showWeatherDropDown.showWeather }
                            CelsiusOrFarenheitDropDown { visible: showWeatherDropDown.showWeather }
                            WeatherServiceDropDown { visible: showWeatherDropDown.showWeather }
                            GpsOrPlaceDropDown { 
                                id: gpsOrPlaceDropDown 
                                visible: showWeatherDropDown.showWeather 
                            }
                            PlaceSelection { visible: (gpsOrPlaceDropDown.thisValue == "Place") }
                        }
                    }
                    CustomDivider {}
                    
                    SectionTemplate {
                        sectionName: qsTr("Other") + Retranslate.onLocaleOrLanguageChanged
                        ShutdownBridge {}
                    }
                    CustomDivider {}
                }
            }
        }
    }
}