/*
 * Copyright (c) 2013-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2
import bb.platform 1.2
import bb.system 1.2
import "Changelog"
import "CustomElements"
import "MainUI"
import "Sheets"

Page {
    id: mainPage
    property string watchUsed: _settings.value("watchUsed", "pebble")
    
    onCreationCompleted: {
        // Creates a MultiCover or SceneCover depending on asset selection
        Application.setCover(activeFrame)
        Application.setMenuEnabled(true)
        
        _app.newChangelog.connect(onNewChangelog)
    }
    
    function onNewChangelog(newChangelogForThisUser) {
        changelogContainer.changelogText = "Changelog:\n" + newChangelogForThisUser
        changelogContainer.visible = true
        changelogContainer.updateBridgeDroid = false
        changelogContainer.updateBridgeWA = false
    }

    Menu.definition: MenuDefinition {
        id: menuDefinition
        settingsAction: SettingsActionItem { 
            onTriggered: { 
                var createdControl = settingsSheet.createObject(mainPage)
                createdControl.open()
            }
        }
        helpAction: HelpActionItem { onTriggered: { helpSheet.open() } }
        actions: [
            ActionItem {
                title: qsTr("About") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/ic_info.png"
                onTriggered: { aboutSheet.open() }
            }
        ] 
    }
    
    attachedObjects: [
        AboutSheet { id: aboutSheet },
        AppCover { id: activeFrame },
        HelpSheet { id: helpSheet },
        ComponentDefinition { id: settingsSheet; SettingsSheet {} },
        TutorialSheet { id: tutorialSheet },
        SystemToast { 
            id: updateBridgeWAToast
            body: qsTr("Sending new settings to Bridge WA, make sure it's running on Pebble and click Ok") + Retranslate.onLocaleOrLanguageChanged
            button.label: qsTr("Ok") + Retranslate.onLocaleOrLanguageChanged
            onFinished: { 
                _app.sendToHL("UPDATE_BRIDGE_WA_SETTINGS", "") 
                settingsSheet.close()
            }
        }
    ]
    
    Container {
        id: mainContainer
        property double numberOfDoubleTaps: 0
        gestureHandlers: [
            DoubleTapHandler {
                onDoubleTapped: {
                    mainContainer.numberOfDoubleTaps++
                    if (mainContainer.numberOfDoubleTaps == 5) {
                        mainContainer.numberOfDoubleTaps = 0
                        _settings.setValue("isRoger", !_settings.value("isRoger", false))
                        devOptions.visible = !devOptions.visible
                        systemToast.body = "Developer options " + (devOptions.visible ? "enabled" : "disabled")
                        systemToast.show()
                    }
                }
                attachedObjects: [
                    SystemToast {
                        id: systemToast
                    }
                ]
            }
        ]

        ChangelogContainer { id: changelogContainer; visible: false; }
        ScrollView {
            visible: !changelogContainer.visible
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                topPadding: _ui.du(3)
                bottomPadding: topPadding
                leftPadding: topPadding
                rightPadding: topPadding
                layout: DockLayout {}
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                Container {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    Container {
                        bottomPadding: _ui.du(3)
                        SegmentedControl {
                            id: segmentedControl
                            Option {
                                id: pebbleOption
                                text: "I Own A Pebble"
                                value: "pebble"
                                selected: (_settings.value("watchUsed", "pebble") == value)
                            }
                            Option {
                                id: vectorOption
                                text: "I Own A Vector"
                                value: "vector"
                                selected: (_settings.value("watchUsed", "pebble") == value)
                            }
                            onSelectedIndexChanged: {
                                _settings.setValue("watchUsed", selectedValue)
                                mainPage.watchUsed = selectedValue
                            }
                        }
                    }
                    PebbleUI { visible: (segmentedControl.selectedOption == pebbleOption) }
                    VectorUI { visible: (segmentedControl.selectedOption == vectorOption) }
                    DeveloperOptions { id: devOptions; visible: _settings.value("isRoger", false) }
                }
            }
        }
    }
}
